ewa.audio.StreamAudioProvider

ewa :: audio :: StreamAudioProvider :: Class StreamAudioProvider |
[hide private]
[frames] | no frames]

# Class StreamAudioProvider

source code

           object --+
                    |
    BaseAudioProvider --+
                        |
                       StreamAudioProvider

Instance Methods | [hide private]
create_combined(self, audioname, rule, **spliceKwargs) | source code
Inherited from `BaseAudioProvider`: `__init__`, `get_extra_master_path`, `get_extra_transcoded_path`, `get_main_path`, `get_playlist` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`